with transfer2 as (
    select
        date_trunc('month', date) as dt,
        -- case type when 'IN' then amount when 'OUT' then -amount when 'BANK_FEE' then -amount else NULL end as amount_rel,
        case type when 'IN' then amount when 'OUT' then -amount when 'BANK_FEE' then -amount when 'IN_FROM_OWN' then amount when 'OUT_TO_OWN' then -amount else NULL end as amount_rel,
        currency,
        coalesce(to_name, '') as to_name
    from raw_transfer
    where
        on_account in ('PL48195000012006000648890002', 'PL91195000012006000648890004', 'PL64195000012006000648890005', 'PL21195000012006000648890003')
        -- on_account in ('PL48195000012006000648890002', 'PL91195000012006000648890004', 'PL64195000012006000648890005')
        -- on_account in ('PL48195000012006000648890002') --, 'PL91195000012006000648890004') --, 'PL64195000012006000648890005')
        and (type not in ('IN_FROM_OWN', 'OUT_FROM_OWN') or (from_account in ('PL02114010100000541244001001', 'PL72114010100000541244001002', 'PL45114010100000541244001003', 'PL18114010100000541244001004')))
	and title not like 'Lokata nr DP%'
),
transfer3 as (
    select dt, case currency when 'PLN' then amount_rel when 'EUR' then amount_rel * :EURPLN_RATE else NULL end as amount_c, to_name from transfer2 
),
monthly_incomes as (
    select
        dt,
        sum(amount_c)/100.0 as month_balance_i
    from transfer3
    where to_name not like '%PSP Zjednoczenie%' and amount_c > 0
    group by dt order by dt
),
monthly_rest as (
    select
        dt,
        sum(amount_c)/100.0 as month_balance_r
    from transfer3
    where to_name not like '%PSP Zjednoczenie%' and amount_c < 0
    group by dt order by dt
),
monthly_psp as (
    select
        dt,
        sum(amount_c)/100.0 as month_balance_p
    from transfer3
    where to_name like '%PSP Zjednoczenie%'
    group by dt order by dt
),
joined as (
    select
        coalesce(monthly_rest.dt,monthly_psp.dt,monthly_incomes.dt) as dt,
        coalesce(month_balance_i, 0) as mi,
        coalesce(month_balance_r, 0) as mr,
        coalesce(month_balance_p, 0) as mp
    from monthly_rest full outer join monthly_psp on monthly_psp.dt = monthly_rest.dt full outer join monthly_incomes on monthly_incomes.dt = monthly_rest.dt
    where
        coalesce(monthly_rest.dt,monthly_psp.dt,monthly_incomes.dt) >= date(:START_DATE)
)
select
    dt, mi, mr, mp,
    --sum(mr + mi + mp) over (order by dt asc rows between unbounded preceding and current row)
    (mr + mi + mp) as sum
from joined;
